Pushed as be6742a

-----Original Message-----
From: devel@edk2.groups.io <devel@edk2.groups.io> On Behalf Of Nate DeSimone
Sent: Monday, November 27, 2023 5:04 PM
To: devel@edk2.groups.io
Cc: Chiu, Chasel <chasel.c...@intel.com>; Gao, Liming 
<gaolim...@byosoft.com.cn>; Dong, Eric <eric.d...@intel.com>
Subject: [edk2-devel] [edk2-platforms][PATCH v1] MinPlatformPkg: Add 
edk2-platforms/Features to PACKAGES_PATH

Cc: Chasel Chiu <chasel.c...@intel.com>
Cc: Liming Gao <gaolim...@byosoft.com.cn>
Cc: Eric Dong <eric.d...@intel.com>
Signed-off-by: Nate DeSimone <nathaniel.l.desim...@intel.com>
---
 Platform/Intel/build.cfg     |  5 +++--
 Platform/Intel/build_bios.py | 11 +++++++----
 2 files changed, 10 insertions(+), 6 deletions(-)

diff --git a/Platform/Intel/build.cfg b/Platform/Intel/build.cfg index 
2ff536bb3e..6ab2ced1a5 100644
--- a/Platform/Intel/build.cfg
+++ b/Platform/Intel/build.cfg
@@ -1,7 +1,7 @@
 # @ build.cfg
 # This is the main/default build configuration file  # -# Copyright (c) 2019 - 
2021, Intel Corporation. All rights reserved.<BR>
+# Copyright (c) 2019 - 2023, Intel Corporation. All rights 
+reserved.<BR>
 # Copyright (c) 2021 - 2022, American Megatrends International LLC.<BR>  # 
SPDX-License-Identifier: BSD-2-Clause-Patent  # @@ -13,7 +13,8 @@ 
WORKSPACE_FSP_BIN = FSP  EDK_TOOLS_BIN = edk2-BaseTools-win32  EDK_BASETOOLS = 
BaseTools  WORKSPACE_DRIVERS = edk2-platforms/Drivers -WORKSPACE_FEATURES = 
edk2-platforms/Features/Intel
+WORKSPACE_FEATURES = edk2-platforms/Features WORKSPACE_FEATURES_INTEL = 
+edk2-platforms/Features/Intel
 WORKSPACE_PLATFORM = edk2-platforms/Platform/Intel  WORKSPACE_SILICON = 
edk2-platforms/Silicon/Intel  WORKSPACE_PLATFORM_BIN = diff --git 
a/Platform/Intel/build_bios.py b/Platform/Intel/build_bios.py index 
43a241c837..c79a653f4d 100755
--- a/Platform/Intel/build_bios.py
+++ b/Platform/Intel/build_bios.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python3
 #
 # @ build_bios.py
 # Builds BIOS using configuration files and dynamically @@ -109,6 +109,8 @@ 
def pre_build(build_config, build_type="DEBUG", silent=False, toolchain=None):
                                                config["WORKSPACE_SILICON"])
     config["WORKSPACE_FEATURES"] = os.path.join(config["WORKSPACE"],
                                                config["WORKSPACE_FEATURES"])
+    config["WORKSPACE_FEATURES_INTEL"] = os.path.join(config["WORKSPACE"],
+                                            
+ config["WORKSPACE_FEATURES_INTEL"])
     config["WORKSPACE_DRIVERS"] = os.path.join(config["WORKSPACE"],
                                                config["WORKSPACE_DRIVERS"])
     config["WORKSPACE_PLATFORM_BIN"] = \ @@ -123,9 +125,10 @@ def 
pre_build(build_config, build_type="DEBUG", silent=False, toolchain=None):
     config["PACKAGES_PATH"] += os.pathsep + config["WORKSPACE_SILICON"]
     config["PACKAGES_PATH"] += os.pathsep + config["WORKSPACE_SILICON_BIN"]
     config["PACKAGES_PATH"] += os.pathsep + config["WORKSPACE_FEATURES"]
-    # add all feature domains in WORKSPACE_FEATURES to package path
-    for filename in os.listdir(config["WORKSPACE_FEATURES"]):
-        filepath = os.path.join(config["WORKSPACE_FEATURES"], filename)
+    config["PACKAGES_PATH"] += os.pathsep + config["WORKSPACE_FEATURES_INTEL"]
+    # add all feature domains in WORKSPACE_FEATURES_INTEL to package path
+    for filename in os.listdir(config["WORKSPACE_FEATURES_INTEL"]):
+        filepath = os.path.join(config["WORKSPACE_FEATURES_INTEL"], 
+ filename)
         # feature domains folder does not contain dec file
         if os.path.isdir(filepath) and \
           not glob.glob(os.path.join(filepath, "*.dec")):
--
2.39.2.windows.1








-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#111862): https://edk2.groups.io/g/devel/message/111862
Mute This Topic: https://groups.io/mt/102842749/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-


Reply via email to